@@ -3,7 +3,7 @@
 # make-tarball.pl Copyright 1999 Mike Hardy, licensed under GPL
 # please see the file COPYING for details on licensing
 #
-# $Horde: horde/scripts/make-tarball.pl,v 1.5.2.6 2000/06/28 02:10:22 bjn Exp $
+# $Horde: horde/scripts/make-tarball.pl,v 1.19 2000/09/28 18:52:06 bjn Exp $
 
 # This is a short script to make an "official" horde or imp tarball
 
@@ -32,6 +32,9 @@
 # Make sure they are sane
 &CheckArguments();
 
+# Check for running as root, set umask, etc.
+&CheckSetSystem();
+
 # Set all of the version strings we're going to need for tags, source, etc
 &SetVersionStrings();
 
@@ -53,6 +56,9 @@ if($MakeDiff) {
     # Check out the next-lowest-patch-level
     &CheckOutTag($OldTagVersionString, $OldDirectoryName);
 
+    # Update the version file with the release version
+    &UpdateVersionFile($OldDirectoryName, $OldSourceVersionString);
+
     # Clean all the non-tarball-bound directories out of it
     &CleanDirectories($OldDirectoryName);
 
@@ -99,6 +105,9 @@ sub DeleteDirectory() {
 sub MakeTarball() {
     my $release_directory = shift;
     
+    print "Setting owner/group to 0/0...\n";
+    system("chown -R 0:0 $release_directory");
+    
     print "Making tarball...\n";
     $tarball_name = $release_directory . ".tar.gz";
     unlink($tarball_name) if(-e $tarball_name);
@@ -144,20 +153,20 @@ sub UpdateVersionFile() {
     open OLDFILE, "<$filename";
     open NEWFILE, ">$newfilename";
     while(<OLDFILE>) {
-	if(/VERSION/) {
-	    print NEWFILE "<?php define('" .
-		$all_caps_module . "_VERSION', '" .
-		    $version_string . "') ?>";
-	} else {
-	    print NEWFILE;
-	}
+        if(/VERSION/) {
+            print NEWFILE "<?php define('" .
+                $all_caps_module . "_VERSION', '" .
+                    $version_string . "') ?>\n";
+        } else {
+            print NEWFILE;
+        }
     }
     close OLDFILE;
     close NEWFILE;
-
+    
     system("mv -f $newfilename $filename");
     if (!$Options{"nocommit"}) {
-	system("cd $directory/; cvs commit -f -m \"Tarball script: building new release - $version_string\" $filename_only > /dev/null 2>&1");
+	system("cd $directory/lib/; cvs commit -f -m \"Tarball script: building new $module release - $version_string\" $filename_only > /dev/null 2>&1");
     }
 }
     
@@ -184,8 +193,13 @@ sub CheckOutTag() {
     my $module = $Options{"module"};
 
     # Use CVS to check the source out
-    print "Checking out tag $mod_version for $module...\n";
-    system("cvs co -r$mod_version $module > /dev/null 2>&1");
+    if ($mod_version eq "HEAD") {
+        print "Checking out HEAD for $module...\n";
+	system("cvs co $module > /dev/null 2>&1");
+    } else {
+        print "Checking out tag $mod_version for $module...\n";
+	system("cvs co -r$mod_version $module > /dev/null 2>&1");
+    }
     
     # Move the source into the directory specified
     print "Moving $module to $directory\n";
@@ -291,6 +305,18 @@ sub CheckArguments() {
 }
 
 
+# Check the command-line arguments and set some internal defaults
+sub CheckSetSystem() {
+
+    # Set umask
+    umask(022);
+
+    # Make sure we're running as root (so we can chown/chmod)
+    die "This script must be as root" if ($> != 0);
+
+}
+
+
 # Show people how to use the damned thing
 sub print_usage() {
     my $message = shift;
